@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import math
 from lxml import etree
 from trytond.transaction import Transaction
@@ -7,10 +7,9 @@ from trytond.cache import Cache
 from trytond.pool import Pool, PoolMeta
 
 __all__ = ['View']
-__metaclass__ = PoolMeta
 
 
-class View:
+class View(metaclass=PoolMeta):
     __name__ = 'ir.ui.view'
     _dashboard_cache = Cache('ir.ui.view.dashboard_id')
 
@@ -113,12 +112,12 @@ class View:
                 else:
                     group.append(element)
             root.append(group)
-        arch = etree.tostring(tree, encoding='utf-8')
+        arch = etree.tostring(tree, encoding='utf-8').decode('utf-8')
         return arch
 
     @classmethod
-    def read(cls, ids, fields_names=None):
-        res = super(View, cls).read(ids, fields_names=fields_names)
+    def read(cls, ids, fields_names):
+        res = super(View, cls).read(ids, fields_names)
         if Transaction().user == 0:
             return res
         dashboard_id = cls.dashboard_id()
